<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
                      "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      xmlns:xi="http://www.w3.org/2001/XInclude">

  <xi:include href="master.html" />

<head>
  <meta content="text/html; charset=UTF-8" http-equiv="content-type" py:replace="''"/>
  <title>Welcome to TurboGears 2.0, standing on the
  shoulders of giants, since 2007</title>
</head>

<body>
    <h2>TurboGears Admin</h2>
    This is a fully-configurable administrative tool to help you administer your website.
    
    <ul>
      <li py:for="model in models"><a href='${model.lower()}/'>${model}s</a></li>
    </ul>
</body>
</html>
